function [Mu,Jacob]=mbgfun(alpha,Energy,Mu_obs,E_edge,E_fluo,HndlPlot,wt)
%MBGFUN_FULL	Background function called by MBACK for
%				full non-linear least-squares optimization
%
% Tsu-Chien Weng, James E. Penner-Hahn, 2000-06-27
% Copyright (c), by the Penner-Hahn group, the University of Michigan

%2001-07-26: Change variable names to be consistent with the paper.

Scale=alpha(1);		% scale factor for Mu_obs
Amp=alpha(2);		% Amplitude of erfc()
xi=alpha(3);		% spectra width in erfc()
coef=alpha(4:end);	% coefficients for polynomials

bg_erfc=Amp*erfc((Energy-E_fluo)/xi);
bg_poly=polyval(coef,Energy-E_edge);
bg_tot=bg_erfc+bg_poly;

set(HndlPlot(1),'XData',Energy,'YData',-bg_tot /Scale,'color','r')
set(HndlPlot(2),'XData',Energy,'YData',-bg_poly/Scale,'color','c')
% set(HndlPlot(3),'XData',Energy,'YData',-bg_erfc/Scale,'color','m')
drawnow

Mu=(Scale*Mu_obs+bg_tot).*wt;

if nargout > 1,
	Nth=length(coef)-1;
	npt=length(Mu);
	Jacob= ...
	[	Mu_obs, ...
		erfc((Energy-E_fluo)/xi), ...
		Amp*2/sqrt(pi)*(Energy-E_fluo)/xi^2.*exp(-((Energy-E_fluo)/xi).^2), ...
		repmat(Energy-E_edge,1, Nth+1).^repmat(Nth:-1:0,npt,1) ...
	].*repmat(wt,1,length(alpha));
end

